import { Integration } from '../integration';
import { Logger } from '../logger';
import { AllTools, ToolApi } from '../tools/types';
type OpenAIVercelModelNames = 'gpt-4' | 'gpt-4-turbo' | 'gpt-3.5-turbo';
type OpenAIVercelConfig = {
    provider: 'OPEN_AI_VERCEL';
    name: OpenAIVercelModelNames;
    toolChoice: 'auto' | 'required';
};
type AnthropicVercelModelNames = 'claude-3-opus-20240229' | 'claude-3-sonnet-20240229' | 'claude-3-haiku-20240307' | 'claude-3-5-sonnet-20240620';
type AnthropicVercelConfig = {
    provider: 'ANTHROPIC_VERCEL';
    name: AnthropicVercelModelNames;
    toolChoice: 'auto' | 'required';
};
type GroqVercelModelNames = 'llama3-groq-70b-8192-tool-use-preview' | 'llama3-groq-8b-8192-tool-use-preview' | 'gemma2-9b-it' | 'gemma-7b-it';
type GroqVercelConfig = {
    provider: 'GROQ_VERCEL';
    name: GroqVercelModelNames;
    toolChoice: 'auto' | 'required';
};
type ModelConfig = OpenAIVercelConfig | AnthropicVercelConfig | GroqVercelConfig;
export declare class Agent<TIntegrations extends Integration[] | undefined = undefined, TTools extends Record<string, ToolApi<TIntegrations>> | undefined = undefined, TKeys extends keyof AllTools<TIntegrations, TTools> = keyof AllTools<TIntegrations, TTools>> {
    #private;
    name: string;
    readonly instructions: string;
    readonly model: ModelConfig;
    readonly enabledTools: Partial<Record<TKeys, boolean>>;
    logger: Logger;
    constructor(config: {
        name: string;
        instructions: string;
        model: ModelConfig;
        enabledTools?: Partial<Record<TKeys, boolean>>;
    });
    /**
     * Set the concrete tools for the agent
     * @param tools
     */
    __setTools(tools: Record<TKeys, ToolApi>): void;
    /**
     * Set the logger for the agent
     * @param logger
     */
    __setLogger(logger: Logger): void;
    private getModelType;
    private convertTools;
    private getAgentParams;
    private createOpenAICompatibleModel;
    text({ messages, onStepFinish, maxSteps, }: {
        messages: string[];
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
    }): Promise<import("ai").GenerateTextResult<{}>>;
    stream({ messages, onStepFinish, maxSteps, }: {
        messages: string[];
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
    }): Promise<import("ai").StreamTextResult<{}>>;
}
export {};
//# sourceMappingURL=index.d.ts.map